<?php
/**
 * Custom template tags for this theme
 *
 * @subpackage Hgw_WhiteBoard
 * @since 1.3.4
 */

 /**
  * site header container - Open
  *
  * @hook hgw_whiteboard_site_header_before
  * @since 1.3.4
  */
 function hgw_whiteboard_site_header_container_open(){

 	$args = array(
 		'id'					=> 'site-header',
 		'class'				=> 'header site-header',
 		'child-class'	=> 'default-max-width flex-sb'
 	);
 	$selectors = apply_filters( 'hgw_whiteboard_site_header_container_selectors', $args );
 	?>
 	<header id="<?php echo esc_attr( $selectors['id'] ); ?>" class="<?php echo esc_attr( $selectors['class'] ); ?>">
 	<div class="<?php echo esc_attr( $selectors['child-class'] ); ?>">
 	<?php
 }

 /**
  * site header container - Close
  *
  * @hook hgw_whiteboard_site_header_after
  * @since 1.3.4
  */
 function hgw_whiteboard_site_header_container_close(){

 	?>
 	</div></header>
 	<?php
 }

 /**
  * site header Brand
  *
  * @hook hgw_whiteboard_site_header
  * @since 1.3.4
  */
 function hgw_whiteboard_site_header_brand(){

 	get_template_part( 'template-parts/site-header/brand');
 }

 /**
  * site header Brand
  *
  * @hook hgw_whiteboard_site_header
  * @since 1.3.4
  */
 function hgw_whiteboard_site_header_menu(){

 	get_template_part( 'template-parts/site-header/menu');
 }

 /**
  * site content container - Open
  *
  * @hook hgw_whiteboard_site_content_before
  * @since 1.3.4
  */
 function hgw_whiteboard_site_content_container_open(){

 	$args = array(
    'id'                  => 'site-content',
    'class'               => 'sitecontent',
    'child-class'         => 'default-max-width flex-sb',
    'second-child-class'  => 'inner-site-content flex-sb',
 	);
 	$selectors = apply_filters( 'hgw_whiteboard_site_content_container_selectors', $args );
 	?>
 	<main id="<?php echo esc_attr( $selectors['id'] ); ?>" class="<?php echo esc_attr( $selectors['class'] ); ?>">
 	<div class="<?php echo esc_attr( $selectors['child-class'] ); ?>">
  <div class="<?php echo esc_attr( $selectors['second-child-class'] ); ?>">
 	<?php
 }

 /**
  * site content container - Close
  *
  * @hook hgw_whiteboard_site_content_after
  * @since 1.3.4
  */
 function hgw_whiteboard_site_content_container_close(){

 	?>
 	</div></div></main>
 	<?php
 }

 /**
  * Secondry sidebar - Close
  *
  * @hook hgw_whiteboard_main_content_before
  * @since 1.3.4
  */
 function hgw_whiteboard_secondary_sidebar(){

   if ( get_theme_mod( 'hgw_sidebar_types', 'default-sidebar' ) == 'two-sidebars') :
     get_sidebar('secondary');
   endif;
 }

 /**
  * Two Sidebar container - Open
  *
  * @hook hgw_whiteboard_main_content_before
  * @since 1.3.4
  */
 function hgw_whiteboard_two_sidebar_content_container_open(){

   $container_class = apply_filters( 'hgw_whiteboard_two_sidebar_content_container_class', 'content-two-sidebar flex-sb' );
   if ( get_theme_mod( 'hgw_sidebar_types', 'default-sidebar' ) == 'two-sidebars') : ?>
    <div class="<?php echo esc_attr( $container_class ); ?>">
   <?php endif;
 }

 /**
  * Two Sidebar container - Close
  *
  * @hook hgw_whiteboard_main_content_after
  * @since 1.3.4
  */
 function hgw_whiteboard_two_sidebar_content_container_close(){

   if ( get_theme_mod( 'hgw_sidebar_types', 'default-sidebar' ) == 'two-sidebars') : ?>
      </div>
   <?php endif;
 }

 /**
  * main content container - Open
  *
  * @hook hgw_whiteboard_main_content_before
  * @since 1.3.4
  */
 function hgw_whiteboard_main_content_container_open(){

   ?>
    <div class="<?php echo esc_attr( apply_filters( 'hgw_whiteboard_main_content_container_class', 'main-content' ) ); ?>">
   <?php
 }

 /**
  * main content container - Close
  *
  * @hook hgw_whiteboard_main_content_after
  * @since 1.3.4
  */
 function hgw_whiteboard_main_content_container_close(){

   ?>
      </div>
   <?php
 }

 /**
  * main content
  * @description: show search form, breadcrumb and run the main loop
  *
  * @hook hgw_whiteboard_main_content
  * @since 1.3.4
  */
 function hgw_whiteboard_main_content_fallback(){

   if ( ! is_singular() ) {
   	/**
   	 * if current page not a singular page
   	 */
   	hgw_whiteboard_breadcrumbs();
   }

   if ( is_search() ) {
   	/**
   	 * if current page is search page
   	 */
   	get_search_form();
   }

   /**
    * Hook hgw_whiteboard_main_loop_before
    */
   do_action( 'hgw_whiteboard_main_loop_before');

   /**
    * Hook hgw_whiteboard_main_loop
    *
    * @hooked hgw_whiteboard_get_main_loop - 10
    */
   do_action( 'hgw_whiteboard_main_loop');

   /**
    * Hook hgw_whiteboard_main_loop_after
    */
   do_action( 'hgw_whiteboard_main_loop_before');
 }

 /**
  * main loop
  *
  * @hook hgw_whiteboard_main_loop
  * @since 1.3.4
  */
 function hgw_whiteboard_get_main_loop(){

   get_template_part( 'template-parts/loop' );
 }

 /**
  * loop content
  *
  * @hook hgw_whiteboard_loop_content
  * @since 1.3.4
  */
 function hgw_whiteboard_get_loop_content(){

   if ( is_singular( ) ) {

     get_template_part( 'template-parts/content', 'singular' );

   }else{

     if ( get_theme_mod( 'hgw_archive_posts_show_types', 'layout1' ) == 'layout3' ) {
       get_template_part( 'template-parts/content', 'layout3' );
     }
     elseif ( get_theme_mod( 'hgw_archive_posts_show_types', 'layout1' ) == 'layout2' ) {
       get_template_part( 'template-parts/content', 'layout2' );
     }else{
       get_template_part( 'template-parts/content', 'layout1' );
     }

   }
 }
